"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkDetectors = checkDetectors;
const scriptInjectionDetector_1 = require("../../detectors/scriptInjectionDetector");
const sqlInjectionDetector_1 = require("../../detectors/sqlInjectionDetector");
const xssDetector_1 = require("../../detectors/xssDetector");
const alertConstants_1 = require("../constants/alertConstants");
function checkDetectors(value, key, issues, options, isKey = false) {
    const { detectSentences, detectReservedWords } = options;
    const keyOrValue = isKey ? 'key' : key;
    if (detectSentences && (0, sqlInjectionDetector_1.isSQLSentence)(value)) {
        issues.push(alertConstants_1.ALERT_MESSAGES.sqlSentenceDetected(keyOrValue, value));
    }
    if (detectReservedWords && (0, sqlInjectionDetector_1.detectSQLInjection)(value)) {
        issues.push(alertConstants_1.ALERT_MESSAGES.sqlInjectionDetected(keyOrValue, value));
    }
    if ((0, xssDetector_1.detectXSS)(value)) {
        issues.push(alertConstants_1.ALERT_MESSAGES.xssDetected(keyOrValue, value));
    }
    if ((0, scriptInjectionDetector_1.detectScriptInjection)(value)) {
        issues.push(alertConstants_1.ALERT_MESSAGES.scriptInjectionDetected(keyOrValue, value));
    }
}
//# sourceMappingURL=detectorUtils.js.map