import { scanUrl } from './scan/scanUrl';
import { scanBody } from './scan/scanBody';
import { scanHeaders } from './scan/scanHeaders';
import { scanFormData } from './scan/scanFormData';
import { scanCookies } from './scan/scanCookies';
import { ScanOptions } from './scan/interfaces/ITScanOptions';
import { ScanRequestParams } from './interfaces/ITScanRequestParams';

const DEFAULT_OPTIONS: ScanOptions = {
  keys: true,
  values: true,
  detectSentences: true,
  detectReservedWords: true,
};

const DEFAULT_SCAN_OPTIONS = {
  checkUrl: DEFAULT_OPTIONS,
  checkBody: DEFAULT_OPTIONS,
  checkHeaders: DEFAULT_OPTIONS,
  checkFormData: DEFAULT_OPTIONS,
  checkCookies: DEFAULT_OPTIONS,
};

export function scanRequest(params: ScanRequestParams): string[] {
  const {
    url = '',
    body = {},
    headers = {},
    formData = new FormData(),
    cookies = {},
    options = DEFAULT_SCAN_OPTIONS,
  } = params;

  const MERGED_OPTIONS = {
    checkUrl: { ...DEFAULT_OPTIONS, ...options.checkUrl },
    checkBody: { ...DEFAULT_OPTIONS, ...options.checkBody },
    checkHeaders: { ...DEFAULT_OPTIONS, ...options.checkHeaders },
    checkFormData: { ...DEFAULT_OPTIONS, ...options.checkFormData },
    checkCookies: { ...DEFAULT_OPTIONS, ...options.checkCookies },
  };

  let issues: string[] = [];

  if (url !== '') {
    const checkUrl = MERGED_OPTIONS.checkUrl;
    if (checkUrl.values) {
      issues = issues.concat(scanUrl(url, checkUrl));
    }
  }

  if (Object.keys(body).length > 0) {
    const checkBody = MERGED_OPTIONS.checkBody;
    issues = issues.concat(scanBody(body, checkBody));
  }

  if (Object.keys(headers).length > 0) {
    const checkHeaders = MERGED_OPTIONS.checkHeaders;
    issues = issues.concat(scanHeaders(headers, checkHeaders));
  }

  if (formData.entries().next().done === false) {
    const checkFormData = MERGED_OPTIONS.checkFormData;
    issues = issues.concat(scanFormData(formData, checkFormData));
  }

  if (Object.keys(cookies).length > 0) {
    const checkCookies = MERGED_OPTIONS.checkCookies;
    issues = issues.concat(scanCookies(cookies, checkCookies));
  }

  return issues;
}
