import { detectScriptInjection } from '../../detectors/scriptInjectionDetector';
import {
  detectSQLInjection,
  isSQLSentence,
} from '../../detectors/sqlInjectionDetector';
import { detectXSS } from '../../detectors/xssDetector';
import { ScanOptions } from '../../scan/interfaces/ITScanOptions';
import { ALERT_MESSAGES } from '../constants/alertConstants';

export function checkDetectors(
  value: string,
  key: string,
  issues: string[],
  options: ScanOptions,
  isKey: boolean = false,
): void {
  const { detectSentences, detectReservedWords } = options;
  const keyOrValue = isKey ? 'key' : key;

  if (detectSentences && isSQLSentence(value)) {
    issues.push(ALERT_MESSAGES.sqlSentenceDetected(keyOrValue, value));
  }
  if (detectReservedWords && detectSQLInjection(value)) {
    issues.push(ALERT_MESSAGES.sqlInjectionDetected(keyOrValue, value));
  }
  if (detectXSS(value)) {
    issues.push(ALERT_MESSAGES.xssDetected(keyOrValue, value));
  }
  if (detectScriptInjection(value)) {
    issues.push(ALERT_MESSAGES.scriptInjectionDetected(keyOrValue, value));
  }
}
